import 'dart:io';
import 'package:flutter/foundation.dart';

enum PlatformType {
  Android,
  Fuchsia,
  IOS,
  Linux,
  MacOS,
  Web,
  Windows,
  Unknown,
}

class PlatformUtils {
  static PlatformType _type;

  static PlatformType get type {
    if(_type == null) _init();
    return _type;
  }

  static bool get isMobile {
    switch(type){
      case PlatformType.Android:
      case PlatformType.IOS:
        return true;
      default:
        return false;
    }
  }

  static bool get isOS {
    switch(type){
      case PlatformType.Android:
      case PlatformType.Fuchsia:
      case PlatformType.IOS:
      case PlatformType.Linux:
      case PlatformType.MacOS:
      case PlatformType.Windows:
        return true;
      default:
        return false;
    }
  }
  static bool get isAndroid => type == PlatformType.Android;
  static bool get isFuchsia => type == PlatformType.Fuchsia;
  static bool get isIOS => type == PlatformType.IOS;
  static bool get isLinux => type == PlatformType.Linux;
  static bool get isMacOS => type == PlatformType.MacOS;
  static bool get isWeb => type == PlatformType.Web;
  static bool get isWindows => type == PlatformType.Windows;

  static void _init(){
    try{
      if(kIsWeb) _type = PlatformType.Web; else//Web checking has to be the first one to avoid "This is no an operating system" exception
      if(Platform.isAndroid) _type = PlatformType.Android; else
      if(Platform.isFuchsia) _type = PlatformType.Fuchsia; else
      if(Platform.isIOS) _type = PlatformType.IOS; else
      if(Platform.isLinux) _type = PlatformType.Linux; else
      if(Platform.isMacOS) _type = PlatformType.MacOS; else
      if(Platform.isWindows) _type = PlatformType.Windows; else
        _type = PlatformType.Unknown;
    } catch(e){
      print(e);
      _type = PlatformType.Unknown;
    }
  }
}

